from matplotlib import pyplot as plt
import pandas as pd


def emg_plot(df: pd.DataFrame) -> None:
    # df es un dataframe con las columnas Elapsed Time,Isquio,Cuadriceps,GLMedio,AductorLargo,Angle
    # Se grafican las columnas Isquio,Cuadriceps,GLMedio,AductorLargo,Angle

    fig, axs = plt.subplots(5, 1, figsize=(15, 14), sharex=True)

    for i, col in enumerate(
        ["Isquio", "Cuadriceps", "GLMedio", "AductorLargo", "Angle"]
    ):
        axs[i].plot(df["Elapsed Time"], df[col])
        axs[i].set_title(col)

    plt.show()


    



import pandas as pd
import os
import numpy as np
import importlib
from scipy import signal

# Low pass filter
sos = signal.butter(2, 5, 'lowpass', fs=250, output='sos')



def load_csv(file_path):
    # df : Elapsed Time,Isquio,Cuadriceps,GLMedio,AductorLargo,Angle

    
    # Load csv
    df = pd.read_csv(file_path)
    # Set dtypes
    df = df.astype(float)

    return df


def example_marcha():
    path = importlib.util.find_spec("ciervo").submodule_search_locations[0] + "/tests/data/marcha"
    files = os.listdir(path)
    files = [f for f in files if f.endswith(".csv")]
    files.sort()
    return [load_csv(os.path.join(path, f)) for f in files]


def example_marcha_larga():
    path = importlib.util.find_spec("ciervo").submodule_search_locations[0] + "/tests/data/marcha_larga"
    files = os.listdir(path)
    files = [f for f in files if f.endswith(".csv")]
    files.sort()
    return [load_csv(os.path.join(path, f)) for f in files]





import numpy as np

# MQTT params
BROKER_HOST = '100.90.57.1'
BROKER_PORT = 1883
PRECISION = np.float64  
CHANNELS = [0, 30, 1, 2, 3, 4]  # Synthetic Stream
NUM_CHANNELS  = len(CHANNELS)
SAMPLE_RATE = 250
